@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0044';
+our $VERSION = '0.0045';
 
 use Moo;
 use strictures 2;
@@ -289,7 +289,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0044
+version 0.0045
 
 =head1 SYNOPSIS
 
@@ -322,6 +322,7 @@ version 0.0044
   my $names = $synth->recall_names;
   # [ 'My favorite setting' ]
 
+  # declare the possible settings
   my %spec = ( # default initial model specification
     order      => [qw(group parameter control group_to param_to bottom top value unit is_default)],
     group      => [],
@@ -337,13 +338,12 @@ version 0.0044
   );
   my $spec_id = $synth->make_spec(%spec);
   my $specs = $synth->recall_spec(id => $spec_id);
+
+  # remove stuff!
   $synth->remove_spec;
-
-  $synth->remove_setting(id => $id1);
-
-  $synth->remove_settings(name => $name);
-
-  $synth->remove_model(model => $model);
+  $synth->remove_setting(id => $id1);     # remove a particular setting
+  $synth->remove_settings(name => $name); # remove all setting sharing the same name
+  $synth->remove_model(model => $model);  # remove the entire model
 
 =head1 DESCRIPTION
 
@@ -496,23 +496,17 @@ specification.
 
 =head1 SEE ALSO
 
+The F<t/01-methods.t> and the F<eg/*.pl> files in this distribution
+
 The L<Mojolicious::Lite> user interface that automates synthesizer
 configuration saving and retrieval is F<eg/synth-config-mojo.pl>.
 
-The F<t/01-methods.t> and F<eg/synth-config-cli.pl> files in this distribution
-
 L<Moo>
 
 L<Mojo::JSON>
 
 L<Mojo::SQLite>
 
-Knob: L<https://codepen.io/jhnsnc/pen/KXYayG>
-
-Switch: L<https://codepen.io/magnus16/pen/grzqMz>
-
-Slider: L<?>
-
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
